@@ -1024,7 +1024,7 @@ package Tk::SMListbox;
 use strict;
 use Carp;
 use vars qw($VERSION);
-$VERSION = '2.2';
+$VERSION = '2.21';
 
 use Tk;
 
@@ -1256,61 +1256,18 @@ sub Populate {
 	#JWT:HAD TO DO THESE THIS WAY INSTEAD OF IN THE CLASS, ELSE THEY DON'T WORK!:
 	$w->bindRows('<Home>',  ['_chgView', 'xview','moveto',0.001]);
 	$w->bindRows('<End>',   ['_chgView', 'xview','moveto',1]);
-	$w->bindRows('<Control-ButtonPress-1>', ['CtrlButtonPress', Ev('index',Ev('@'))]);
 
-	$w->bindRows('<ButtonPress-1>', [sub {
+	$w->bindRows('<ButtonPress-1>', [sub {  #ONLY NEED THIS BINDING TO TAKE FOCUS IF -takefocus == 1 (CLICK-TO-FOCUS):
 		my $w = shift;
+
+		#WARNING:  WE DON'T REALLY HAVE ACCESS TO WHERE THE MOUSE WAS CLICKED, AS "Ev(*)" DATA IS
+		#NOT PROPERLY PASSED TO THESE BINDINGS IF THE COLUMNS DON'T ALREADY EXIST WHEN THEY'RE SET UP!:
 		if (Tk::Exists($w)) {
 			return  if ($w->{Configure}{'-state'} =~ /d/o);
 
-			if (!$w->{'_hasfocus'} && $w->{'_ourtakefocus'}) {
-				$w->focus;
-				#OBTAIN INDEX OF ROW MOUSE CLICKED ON (I CAN'T FIGURE OUT WHAT TO DO W/THIS "Ev STUFF"?)! :(
-				my $mousexy = '@'.($w->pointerx-$w->rootx).','.($w->pointery-$w->rooty);
-				my $clickedon = $w->index($mousexy) - 1;  #FOR SOME REASON, IT'S ALWAYS OFF-BY-1!
-				$w->activate($clickedon)  if ($clickedon >= 0);  #EMULATE HMListbox.
-			}
-		}
-	}, Ev('index',Ev('@'))]
-	);
-
-	$w->bindRows('<ButtonRelease-1>', [sub {
-		my $w = shift;
-		my $clickedon = $_[0];
-
-		if (Tk::Exists($w)) {
-			return  if ($w->{Configure}{'-state'} =~ /d/o);
 			$w->focus  if (!$w->{'_hasfocus'} && $w->{'_ourtakefocus'});
 		}
-	}, Ev('index',Ev('@'))]
-	);
-
-	$w->bindRows('<Alt-ButtonPress-1>', [sub {
-		my $w = shift;
-		my $clickedon = $_[0];
-
-		if (Tk::Exists($w)) {
-			return  if ($w->{Configure}{'-state'} =~ /d/o);
-
-			my $index = $w->_firstVisible->index('anchor');
-			$w->focus  if (!$w->{'_hasfocus'} && $w->{'_ourtakefocus'});
-			$w->activate($index);
-		}
-	}, Ev('index',Ev('@'))]
-	);
-}
-
-sub CtrlButtonPress {
-	my $w = shift;
-	return  unless (defined $w->_firstVisible);
-
-	my $clickedon = $w->_firstVisible->index('active');
-	my @cursel = $w->_firstVisible->curselection;
-	if (Tk::Exists($w)) {
-		return  if ($w->{Configure}{'-state'} =~ /d/o);
-
-		$w->activate($w->_firstVisible->index('anchor'));
-	}
+	}]);
 }
 
 sub scrollbarfocus { #JWT:  ALLOW THEM TO SPECIFY WHICH, IF ANY SCROLLBARS TAKE FOCUS:
@@ -1447,6 +1404,7 @@ sub takefocus {
 	my ($w, $val, $byus) = @_;
 	return $w->{Configure}{'-takefocus'}  unless (defined $val);
 
+	#JWT:NEEDS TO BE '' INSTEAD OF 1 FOR Tk (SO WE KEEP IT IN OUR OWN VARIABLE FOR OUR USE)!:
 	$w->{'_ourtakefocus'} = $val  unless (defined $byus);
 	$w->{Configure}{'-takefocus'} = ($val =~ /0/o) ? 0 : '';
 }
@@ -1515,6 +1473,8 @@ sub _bindSubwidgets {
 		return '';
 	}
 	my @args = ('_bindCallback', $callback);
+	#WARNING:  IF THESE ARE BOUND BEFORE THE COLUMNS ARE CREATED, THEN "Ev(*)" DATA IS NOT
+	#PROPERLY PASSED TO THE CALLBACKS WHEN THE BINDINGS ARE BOUND LATER WHEN THE COLUMNS ARE CREATED!:
 	foreach (@{$w->{'_columns'}}) {
 		my $sw = $_->Subwidget($subwidget);
 		if ($sw->class ne 'SMCListbox') {
@@ -1559,9 +1519,7 @@ sub _dataExtend {
 	if ($mode eq 'extended') {
 		$w->activate($el);
 		$w->see($el);
-		if ($w->selectionIncludes('anchor')) {
-			$w->_firstVisible->Motion($el)
-		}
+		$w->_firstVisible->Motion($el)  if (defined($w->_firstVisible) && $w->selectionIncludes('anchor'));
 	} elsif ($mode eq 'multiple') {
 		$w->activate($el);
 		$w->see($el)
@@ -1570,9 +1528,7 @@ sub _dataExtend {
 
 sub _deselectAll {
 	my $w = shift;
-	if ($w->cget('-selectmode') ne 'browse') {
-		$w->selectionClear(0, 'end');
-	}
+	$w->selectionClear(0, 'end')  if ($w->cget('-selectmode') ne 'browse');
 }
 
 ## implements sorting and dragging & drop of a column
@@ -1766,7 +1722,7 @@ sub _yscrollCallback  {
 	unless (defined($top)) {
 		# Called internally
 		my $c = $w->_firstVisible;
-		if (Exists($c) && $c->ismapped){
+		if (Tk::Exists($c) && $c->ismapped) {
 			($top,$bottom) = $c->yview;
 		} else {
 			($top,$bottom) = (0,1);
@@ -1913,9 +1869,9 @@ sub columnInsert {
 	my %opts = ();
 
 	## Copy these options from the megawidget.
-	foreach (qw/-background -foreground -headerbackground -headerforeground -font -height 
-			-resizeable -selectbackground -selectforeground -disabledforeground 
-			-selectborderwidth -selectmode -separatorcolor 
+	foreach (qw/-background -foreground -headerbackground -headerforeground -font -height
+			-resizeable -selectbackground -selectforeground -disabledforeground
+			-selectborderwidth -selectmode -separatorcolor
 			-separatorwidth -sortable -textwidth -reversearrow -state/) 
 	{
 		$opts{$_} = $w->cget($_) if defined $w->cget($_);
